package com.codegeist.fisheye.internal.service;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

import com.codegeist.fisheye.domain.QueryResultData;
import com.codegeist.fisheye.domain.query.IQueryMatchListener;
import com.codegeist.fisheye.domain.query.Query.ReturnValue;

// TODO this doesn't fit with all other types of handlers.  We don't really want the result being returned
public class QueryResultsHandler extends DefaultHandler implements Handler<QueryResultData> {

	private QueryResultData result;
	private Object[] currentRow;
	private int currentColumn;
	private final ReturnValue[] columns;
	private final StringBuilder buffer = new StringBuilder();
	private final IQueryMatchListener matchListener;
	
	public QueryResultsHandler(ReturnValue[] columns, IQueryMatchListener matchListener) {
		this.columns = columns;
		this.matchListener = matchListener;
		result = new QueryResultData(columns);
	}
	
	@Override
	public void startDocument() throws SAXException {
		currentColumn = 0;
	}
	
	@Override
	public void startElement(String uri, String localName, String name, Attributes attributes) throws SAXException {
		buffer.setLength(0);
		if ("row".equals(localName)) {
			currentColumn = 0;
			currentRow = new Object[columns.length];
		}
	}
	
	@Override
	public void characters(char[] ch, int start, int length) throws SAXException {
		buffer.append(ch, start, length);
	}
	
	@Override
	public void endElement(String uri, String localName, String name) throws SAXException {
		
		if ("row".equals(localName)) {
			result.addLine(currentRow);
			try {
				matchListener.matchData(columns, currentRow);
			} catch (Exception e) {
				e.printStackTrace();
				// TODO log this or throw another exception
			}
		} else {
			// XXX check for out of bounds
			ReturnValue value = columns[currentColumn];
			if (!value.getColumnName().equals(localName)) {
				// TODO throw an exception
			}
			
			currentRow[currentColumn] = value.getAttribute().fromString(buffer.toString());
			currentColumn++;
		}
		
		buffer.setLength(0);
	}
	
	@Override
	public void endDocument() throws SAXException {
		// TODO Auto-generated method stub
		super.endDocument();
	}
	
	public QueryResultData getResult() {
		return result;
	}

}
