package com.codegeist.fisheye.internal.ui.connection;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.layout.GridLayoutFactory;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

public class NewConnectionWizardPage extends WizardPage {

	private Text name;
	private Text location;


	public NewConnectionWizardPage() {
		super("NewConnection", "New FishEye Connection", null);
		setDescription("Enter connection details of the FishEye server");
	}
	
	public void createControl(Composite parent) {
		
		ModifyListener validateListener = new ModifyListener() {
			
			public void modifyText(ModifyEvent e) {
				validate();
			}
		};
		
		Composite c = new Composite(parent, SWT.NONE);
		
		GridLayoutFactory.swtDefaults().numColumns(2).margins(0, 0).applyTo(c);
		GridDataFactory grabbingGridDataFactory = GridDataFactory.fillDefaults().grab(true, false);
		
		Label lblName = new Label(c, SWT.NONE);
		lblName.setText("Name:");
		
		name = new Text(c, SWT.BORDER | SWT.SINGLE);
		name.addModifyListener(validateListener);

		Label lblLocation = new Label(c, SWT.NONE);
		lblLocation.setText("URL:");
		
		location = new Text(c, SWT.BORDER | SWT.SINGLE);
		location.addModifyListener(validateListener);
		
		grabbingGridDataFactory.applyTo(name);
		grabbingGridDataFactory.applyTo(location);
		
		setPageComplete(false);
		
		setControl(c);
	}

	private void validate() {
		setPageComplete(false);
		
		if (name.getText().length() == 0) {
			setErrorMessage("Name must be supplied");
			return;
		}
		
		if (location.getText().length() == 0) {
			setErrorMessage("URL must be supplied");
			return;
		}
		
		try {
			new URL(location.getText());
		} catch (MalformedURLException e) {
			setErrorMessage("Invalid URL");
			return;
		}
		
		// TODO check if the name is in use
		
		setPageComplete(true);
		setErrorMessage(null);
	}
	
	public String getConnectionName() {
		return name.getText();
	}
	

	public String getConnectionUrl() {
		return location.getText();
	}
	
}
